@@ -336,9 +336,9 @@ class VscGraphicItem3Term(GenericDiagramWidget, QGraphicsRectItem):
             pe = menu.addAction('Enable/Disable')
             pe_icon = QIcon()
             if self.api_object.active:
-                pe_icon.addPixmap(QPixmap(":/Icons/icons/uncheck_all.svg"))
+                pe_icon.addPixmap(QPixmap(":/Icons/icons/uncheck_all.png"))
             else:
-                pe_icon.addPixmap(QPixmap(":/Icons/icons/check_all.svg"))
+                pe_icon.addPixmap(QPixmap(":/Icons/icons/check_all.png"))
             pe.setIcon(pe_icon)
             pe.triggered.connect(lambda: self.set_enable(not self.api_object.active))
 
@@ -353,7 +353,7 @@ class VscGraphicItem3Term(GenericDiagramWidget, QGraphicsRectItem):
             menu.addSeparator()
             ra2 = menu.addAction('Delete')
             del_icon = QIcon()
-            del_icon.addPixmap(QPixmap(":/Icons/icons/delete3.svg"))
+            del_icon.addPixmap(QPixmap(":/Icons/icons/delete3.png"))
             ra2.setIcon(del_icon)
             ra2.triggered.connect(self.delete)
 
@@ -363,30 +363,30 @@ class VscGraphicItem3Term(GenericDiagramWidget, QGraphicsRectItem):
             add_menu_entry(menu=menu,
                            text="Control V AC from DC+",
                            function_ptr=self.control_v_from,
-                           icon_path=":/Icons/icons/edit.svg")
+                           icon_path=":/Icons/icons/edit.png")
 
             add_menu_entry(menu=menu,
                            text="Control V AC from AC",
                            function_ptr=self.control_v_to,
-                           icon_path=":/Icons/icons/edit.svg")
+                           icon_path=":/Icons/icons/edit.png")
 
             menu.addSeparator()
 
             ra6 = menu.addAction('Plot profiles')
             plot_icon = QIcon()
-            plot_icon.addPixmap(QPixmap(":/Icons/icons/plot.svg"))
+            plot_icon.addPixmap(QPixmap(":/Icons/icons/plot.png"))
             ra6.setIcon(plot_icon)
             ra6.triggered.connect(self.plot_profiles)
 
             ra4 = menu.addAction('Assign rate to profile')
             ra4_icon = QIcon()
-            ra4_icon.addPixmap(QPixmap(":/Icons/icons/assign_to_profile.svg"))
+            ra4_icon.addPixmap(QPixmap(":/Icons/icons/assign_to_profile.png"))
             ra4.setIcon(ra4_icon)
             ra4.triggered.connect(self.assign_rate_to_profile)
 
             ra5 = menu.addAction('Assign active state to profile')
             ra5_icon = QIcon()
-            ra5_icon.addPixmap(QPixmap(":/Icons/icons/assign_to_profile.svg"))
+            ra5_icon.addPixmap(QPixmap(":/Icons/icons/assign_to_profile.png"))
             ra5.setIcon(ra5_icon)
             ra5.triggered.connect(self.assign_status_to_profile)
 
