@@ -260,6 +260,9 @@ class ConfigurationMain(ResultsMain):
                 "consider_contingencies": self.ui.considerContingenciesOpfCheckBox,
                 "maximize_area_exchange": self.ui.opfMaximizeExcahngeCheckBox,
                 "unit_commitment": self.ui.opfUnitCommitmentCheckBox,
+                "consider_ramps": self.ui.opfConsiderRampsCheckBox,
+                "consider_time_up_down": self.ui.opfConsiderUpDownTimeCheckBox,
+                "area_spinning_reserve": self.ui.opfSpinningReserveCheckBox,
                 "add_opf_report": self.ui.addOptimalPowerFlowReportCheckBox,
                 "robust_mip": self.ui.fixOpfCheckBox,
                 "save_mip": self.ui.save_mip_checkBox,
